1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
|
diff --git a/ipc/chromium/src/base/message_pump_libevent.cc b/ipc/chromium/src/base/message_pump_libevent.cc
index 9ce230c..d980f9e 100644
--- a/ipc/chromium/src/base/message_pump_libevent.cc
+++ b/ipc/chromium/src/base/message_pump_libevent.cc
@@ -18,18 +18,18 @@
#include "event.h"
#include "mozilla/UniquePtr.h"
// This macro checks that the _EVENT_SIZEOF_* constants defined in
// ipc/chromiume/src/third_party/<platform>/event2/event-config.h are correct.
-#define CHECK_EVENT_SIZEOF(TYPE, type) \
- static_assert(_EVENT_SIZEOF_##TYPE == sizeof(type), \
- "bad _EVENT_SIZEOF_"#TYPE);
-
-CHECK_EVENT_SIZEOF(LONG, long);
-CHECK_EVENT_SIZEOF(LONG_LONG, long long);
-CHECK_EVENT_SIZEOF(PTHREAD_T, pthread_t);
-CHECK_EVENT_SIZEOF(SHORT, short);
-CHECK_EVENT_SIZEOF(SIZE_T, size_t);
-CHECK_EVENT_SIZEOF(VOID_P, void*);
+#define CHECKEVENT__SIZEOF(TYPE, type) \
+ static_assert(EVENT__SIZEOF_##TYPE == sizeof(type), \
+ "bad EVENT__SIZEOF_"#TYPE);
+
+CHECKEVENT__SIZEOF(LONG, long);
+CHECKEVENT__SIZEOF(LONG_LONG, long long);
+CHECKEVENT__SIZEOF(PTHREAD_T, pthread_t);
+CHECKEVENT__SIZEOF(SHORT, short);
+CHECKEVENT__SIZEOF(SIZE_T, size_t);
+CHECKEVENT__SIZEOF(VOID_P, void*);
// Lifecycle of struct event
// Libevent uses two main data structures:
|
@@ -18,18 +18,18 @@
#include "event.h"
#include "mozilla/UniquePtr.h"
-// This macro checks that the _EVENT_SIZEOF_* constants defined in
+// This macro checks that the EVENT__SIZEOF_* constants defined in
// ipc/chromiume/src/third_party/<platform>/event2/event-config.h are correct.